@@ -55,7 +55,6 @@ class CliHandler:
         if not silent:
             logging.basicConfig(
                 format="%(message)s",
-                encoding="utf-8",
                 level=logging.INFO,
             )
         self._report_errors = report_errors
@@ -84,16 +83,26 @@ class CliHandler:
                 sentry_sdk.flush()
             return f"Could not load config ({error_name(e)})"
 
-        logger.info("Starting to bootstrap")
+        logger.info("Running 'setup'")
         try:
+            create_graph_func = getattr(
+                config,
+                "setup",
+                getattr(
+                    config,
+                    "create_system_graph",
+                    getattr(config, "bootstrap", None),
+                ),
+            )
+            if create_graph_func is None:
+                return "You have to define a `setup` function in your config."
             try:
-                graph = config.bootstrap(strict_mode=strict_mode)
-                # TODO
+                graph = create_graph_func(strict_mode=strict_mode)
             except TypeError:
                 logger.warning(
-                    "Please pass kwargs into bootstrap! this will be deprecated soon!"
+                    "Please pass kwargs into `setup`! this will be deprecated soon!"
                 )
-                graph = config.bootstrap()
+                graph = create_graph_func()
         except KeyboardInterrupt:
             return "Manual exit"
         except Exception as e:
@@ -102,7 +111,7 @@ class CliHandler:
             if self._report_errors:
                 sentry_sdk.capture_exception(e)
                 sentry_sdk.flush()
-            return f"Could not run bootstrap ({error_name(e)})"
+            return f"Could not run `setup` ({error_name(e)})"
         logger.info("Graph loaded")
 
         api_key = os.getenv("CODOC_API_KEY")
