@@ -6,7 +6,9 @@ viewer friendly.
 """
 from .class_diagram import class_diagram_filter
 from .children_based import get_children_of
+from .children_based import get_children_of as content_of
 from .depth_based import get_depth_based_filter
+from .depth_based import get_depth_based_filter as depth_based
 from .external_exclusion import exclude_external
 from .type_exclusion_filter import (
     exclude_classes,
@@ -36,4 +38,6 @@ __all__ = [
     "exclude_external",
     "filter_by_regex",
     "exclude_by_regex",
+    "depth_based",
+    "content_of",
 ]
